* code for (approximately) replicating Cook and Tauchen (1982) and Ponicki and Gruenewald (2006), used in Roodman (2015)

**********************************************
*** Cook & Tauchen
**********************************************
* odbc load, clear dsn("Sin taxes") exec("select * from [U.S. state panel]")
use "US state panel", clear
drop if inlist(Postal_code,"HI","AK","DC")
tsset FIPS Year
gen long DeathsNonalcAdj = DeathsAdj - DeathsAlcAdj
foreach var in "" Alc AlcAdj AlcCauseAdj Cirr CirrAdj AlcCirr AlcCirrAdj NonalcAdj TrafAdj {
	gen double Deaths`var'Pop = Deaths`var'/(Pop1844*15/27+Pop4564+Pop65) * 100000 // divide cirrhosis deaths, 15+, by approximate 30+ population = ~30+ cirrhosis death rate
	gen double lDeaths`var'Pop = ln(Deaths`var'Pop)
	gen double lDeaths`var'PopWt = sqrt(Deaths`var' / (1 - Deaths`var'Pop / 100000)) // weight for log model. See http://books.google.com/books?id=-Ji1ZaUg7gcC&lpg=PP1&dq=maddala%20limited%20dependent&pg=PA29#v=onepage&q&f=false
}
replace SpirPx = SpirPx / .75 * 3.78 // convert from 750ML bottle of J&B to gallons
gen double SpirPxReal = SpirPx / CPI * 33.4 // 1967 $
gen double SpirTxReal = SpirTx / CPI * 33.4 // 1967 $
gen double PersIncPop = PersInc/Pop/1000
gen double PersIncPopReal = PersIncPop / CPI * 33.4
gen double SpirCxPop = SpirCx / Pop14 // doesn't match C&T but matches LaVallee, Williams, and Yi (2009), Table 1 extremely well
gen double lSpirCxPop = ln(SpirCxPop)

* population-weighted average spirits price 1967 $/gallon by year.
tabstat SpirPxReal [aw = Pop15] if Cook_Tauchen_sample, by(Year)

* Cook & Tauchen Table 1
tabstat PersIncPopReal SpirTxReal SpirCxPop DeathsCirrAdjPop if inlist(Year, 1962, 1965, 1968, 1971, 1974, 1977) & Cook_Tauchen_sample, by(Year)

cap program drop OutregThis
program define OutregThis
	syntax, [ctitle(string)]
	tempname column hold
	
	outreg, clear(`column')

	outreg, keep(L(0/1).(SpirTxReal)) ///
	        ctitle("", `"`ctitle'"') ///
					stats(b se ci) ///
					starlevels(10 5 1) ///
					dbldiv(,) ///
					tdec(2) ///
					noautosumm ///
					store(`column') ///
					nodisplay
					
	local N = e(N) + 30

	_est hold `hold', copy restore
	
	nlcom _b[SpirTxReal] + _b[L.SpirTxReal], post
	
	outreg, stats(b t_abs ci) ///
					starlevels(10 5 1) ///
					dbldiv(,) ///
					bdec(3) ///
					rtitle(Sum) ///
					noautosumm ///
					addrows("N", `=e(N)+30') ///
					append(`column') ///
					store(`column') ///
					nodisplay
					
	outreg, replay merge(`column')
end

outreg, clear
xi i.Year i.FIPS

* Table 2
xtregar lSpirCxPop        L(0/1).(SpirTxReal PersIncPopReal) _IYear_1963-_IYear_1977 if Cook_Tauchen_sample & Year>=1962 & Year<=1977, fe
xtregar lDeathsCirrAdjPop L(0/1).(SpirTxReal PersIncPopReal) _IYear_1963-_IYear_1977 if Cook_Tauchen_sample & Year>=1962 & Year<=1977, fe
OutregThis, ctitle(Replication)

* expand sample
xtregar lSpirCxPop        L(0/1).(SpirTxReal PersIncPopReal) _IYear_1962-_IYear_2004 if Cook_Tauchen_sample, fe
xtregar lDeathsCirrAdjPop L(0/1).(SpirTxReal PersIncPopReal) _IYear_1962-_IYear_2004 if Cook_Tauchen_sample, fe
OutregThis, ctitle(Expansion to 1960-2004)

* expand outcome too
xtregar lDeathsAlcCauseAdjPop L(0/1).(SpirTxReal PersIncPopReal) _IYear* if Cook_Tauchen_sample, fe
OutregThis, ctitle(Expansion to 1960-2004, alcohol-caused)

* falsification test
xtregar lDeathsNonalcAdjPop L(0/1).(SpirTxReal PersIncPopReal) _IYear* if Cook_Tauchen_sample, fe
OutregThis, ctitle("Expansion to 1960-2004, non-alcohol deaths")

outreg using "Cook & Tauchen", replay coljust(l{c}c) replace // Roodman table

* Granger tests. AIC and BIC favor 2 lags. Show (mostly) one-way causality from taxes to cirrhosis deaths, no causality for non-alcohol deaths
ivreg2 lDeathsCirrAdjPop   L(1/2).(lDeathsCirrAdjPop   SpirTxReal PersIncPopReal) _I* if Cook_Tauchen_sample [aw = lDeathsCirrAdjPopWt], cluster(FIPS Year)
test L.SpirTxReal L2.SpirTxReal
ivreg2 SpirTxReal L(1/2).(SpirTxReal lDeathsCirrAdjPop PersIncPopReal) _I* if Cook_Tauchen_sample, cluster(FIPS Year)
test L.lDeathsCirrAdjPop L2.lDeathsCirrAdjPop
ivreg2 lDeathsAlcCauseAdjPop   L(1/2).(lDeathsAlcCauseAdjPop   SpirTxReal PersIncPopReal) _I* if Cook_Tauchen_sample [aw = lDeathsAlcAdjPopWt], cluster(FIPS Year)
test L.SpirTxReal L2.SpirTxReal
ivreg2 SpirTxReal L(1/2).(SpirTxReal lDeathsAlcCauseAdjPop PersIncPopReal) _I* if Cook_Tauchen_sample, cluster(FIPS Year)
test L.lDeathsAlcCauseAdjPop L2.lDeathsAlcCauseAdjPop


**********************************************
*** Ponicki & Gruenewald (results not used in Roodman)
**********************************************
* odbc load, clear dsn("Sin taxes") exec("select * from [U.S. state panel]")
use "US state panel", clear
tsset FIPS Year
foreach var in "" Alc AlcCause AlcCirr {
	gen double Deaths`var'Pop = Deaths`var'/Pop14 * 100000
	gen double lDeaths`var'Pop = ln(Deaths`var'Pop)
}
foreach bev in Wine Beer Spir {
	gen double `bev'TxReal = `bev'Tx / CPI * 172.2 // 2000 $
}
foreach var in Pop3544 Pop4554 Pop5564 Pop65 {
	gen double s`var' = `var' / Pop15
}
gen double PersIncPop = PersInc/Pop/1000
gen double PersIncPopReal = PersIncPop / CPI * 172.2

replace WineTx = WineTx * 2.201433767 // convert taxes to liters of pure ethanol. See ACCRAadj.xls, Documentation tab
replace BeerTx = BeerTx * 0.189370647
replace SpirTx = SpirTx * 0.614353609

* Table 1, models 1 & 2?
xtregar lDeathsAlcCirrPop L(0/1).(SpirTxReal PersIncPopReal) /*i.Year*/ sPop* if Year>=1971 & Year<=1998 & Cook_Tauchen_sample, re
xtregar lDeathsAlcCirrPop L(0/1).(   *TxReal PersIncPopReal) /*i.Year*/ sPop* if Year>=1971 & Year<=1998 & Cook_Tauchen_sample, re

* FE analog thereof
xtregar lDeathsAlcCirrPop L(0/1).(SpirTxReal PersIncPopReal) /*i.Year*/ sPop* if Year>=1971 & Year<=1998 & Cook_Tauchen_sample, fe
xtregar lDeathsAlcCirrPop L(0/1).(   *TxReal PersIncPopReal) /*i.Year*/ sPop* if Year>=1971 & Year<=1998 & Cook_Tauchen_sample, fe

